@@ -51,7 +51,7 @@ BEGIN {
         alt_stat
     );
     
-    $VERSION = '1.42';
+    $VERSION = '1.43';
 
     XSLoader::load(__PACKAGE__, $VERSION);
 }
@@ -1599,11 +1599,11 @@ License or the Artistic License, as specified in the F<LICENCE> file.
 
 =head1 VERSION
 
-Version 1.42
+Version 1.43
 
 =head1 DATE
 
-03 Mar 2005
+01 Jun 2005
 
 =head1 HISTORY
 
